@@ -253,6 +253,14 @@ void personal_photo_frame_button_release (GtkWidget *widget, GdkEventButton *eve
 				dbus_connection_unref(conn);
 			}
 		}
+	} else {
+		DBusConnection *conn = dbus_bus_get(DBUS_BUS_SESSION, NULL);
+		if (self->priv->singleMode) {
+			hildon_mime_open_file (conn, self->priv->singleFilename);
+		} else {
+			hildon_mime_open_file (conn, self->priv->slideshowFilename);
+		}
+		dbus_connection_unref(conn);
 	}
 	
 	gtk_widget_queue_draw (GTK_WIDGET (self));
